@@ -23,7 +23,7 @@ def stripper(chars):
 
 strip = stripper(None)
 
-# Note: `pattern` can be a string or a compiled regular expression
+# `pattern` can be a string or a compiled regular expression
 def translator(pattern, replacement):
     def fn(x):
         if isinstance(pattern, re._pattern_type):
@@ -31,6 +31,14 @@ def translator(pattern, replacement):
         return x.replace(pattern, replacement)
     return fn
 
+# `pattern` can be a string or a compiled regular expression
+def swapper(pattern, replacement):
+    def fn(x):
+        if isinstance(pattern, re._pattern_type):
+            return replacement if re.search(pattern, x) else x
+        return replacement if pattern in x else x
+    return fn
+
 # `test` can be a function or a list/tuple
 def defaulter(test, default_value):
     def fn(x):
